<?php

namespace Drupal\digital_signage_platform;

use Drupal\digital_signage_device\DeviceInterface;

/**
 * Interface for digital_signage_platform plugins.
 */
interface PlatformInterface {

  /**
   * Initialize the plugin.
   */
  public function init();

  /**
   * Returns the translated plugin label.
   *
   * @return string
   *   The translated title.
   */
  public function label(): string;

  /**
   * Provide a list of extra base fields required for the platform's schedule.
   *
   * @param array $fields
   */
  public function scheduleBaseFields(array &$fields);

  /**
   * Syncs devices of this platform.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function syncDevices();

  /**
   * Receive a list of all devices from the platform.
   *
   * @return \Drupal\digital_signage_device\Entity\Device[]
   */
  public function getPlatformDevices(): array;

  /**
   * @param \Drupal\digital_signage_device\DeviceInterface $device
   * @param bool $debug
   * @param bool $reload_css
   * @param bool $reload_assets
   */
  public function pushSchedule(DeviceInterface $device, $debug = FALSE, $reload_css = FALSE, $reload_assets = FALSE);

}
