<?php

namespace Drupal\digital_signage_schedule\Commands;

use Drupal\digital_signage_schedule\ScheduleManager;
use Drush\Commands\DrushCommands;

/**
 * A Drush commandfile for digital signage devices.
 */
class ScheduleCommands extends DrushCommands {

  /**
   * @var \Drupal\digital_signage_schedule\ScheduleManager
   */
  protected $scheduleManager;

  /**
   * DigitalSignageScheduleCommands constructor.
   *
   * @param \Drupal\digital_signage_schedule\ScheduleManager $schedule_manager
   */
  public function __construct(ScheduleManager $schedule_manager) {
    $this->scheduleManager = $schedule_manager;
    parent::__construct();
  }

  /**
   * Command description here.
   *
   * @usage digital-signage-schedule:create
   *   Synchronises all devices with all enabled platforms.
   *
   * @command digital-signage-schedule:create
   * @option device
   * @option force
   * @option debugmode
   * @option reloadcss
   * @option reloadassets
   * @option entitytype
   * @option entityid
   * @aliases dssc
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function createSchedules(array $options = ['device' => NULL, 'force' => FALSE, 'debugmode' => FALSE, 'reloadcss' => FALSE, 'reloadassets' => FALSE, 'entitytype' => NULL, 'entityid' => NULL]) {
    if ($options['entitytype'] !== NULL && $options['entityid'] === NULL) {
      $this->io()->error('Entity ID is required if entity type is given.');
      return;
    }
    $this->scheduleManager->createSchedules($options['device'], $options['force'], $options['debugmode'], $options['reloadcss'], $options['reloadassets'], $options['entitytype'], $options['entityid']);
  }

}
