<?php

namespace Drupal\digital_signage_schedule\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\digital_signage_schedule\ScheduleSpec;

/**
 * Plugin implementation of the 'Preview' formatter.
 *
 * @FieldFormatter(
 *   id = "digital_signage_schedule_preview",
 *   label = @Translation("Preview"),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
class Preview extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(FieldDefinitionInterface $field_definition): bool {
    /** @noinspection PhpUndefinedMethodInspection */
    return
      $field_definition->toArray()['entity_type'] === 'digital_signage_device' &&
      $field_definition->getSetting('target_type') === 'digital_signage_schedule';
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    /** @var \Drupal\digital_signage_device\DeviceInterface $device */
    $device = $items->getEntity();
    $settings = new ScheduleSpec($device);
    return [
      [
        '#type' => 'button',
        '#value' => $this->t('Open diagram'),
        '#attributes' => [
          'class' => ['digital-signage', 'diagram'],
          'device-id' => $device->id(),
        ],
      ],
      [
        '#type' => 'button',
        '#value' => $this->t('Open preview'),
        '#attributes' => [
          'class' => ['digital-signage', 'preview'],
          'device-id' => $device->id(),
        ],
        '#attached' => [
          'drupalSettings' => [
            'digital_signage' => [
              'devices' => [
                $device->id() => [
                  'orientation' => $device->getOrientation(),
                  'proportion' => $device->getWidth() / $device->getHeight(),
                  'schedule' => $settings->getSpec(),
                ],
              ],
            ],
          ],
          'library' => [
            'digital_signage_schedule/preview',
          ],
        ],
      ],
    ];
  }

}
