<?php

namespace Drupal\digital_signage_schedule;

use Drupal\Core\Url;
use Drupal\digital_signage_device\DeviceInterface;

class ScheduleSpec {

  /**
   * @var \Drupal\digital_signage_device\DeviceInterface
   */
  protected $device;

  /**
   * ScheduleSpec constructor.
   *
   * @param \Drupal\digital_signage_device\DeviceInterface $device
   */
  public function __construct(DeviceInterface $device) {
    $this->device = $device;
  }

  /**
   * @return array
   */
  public function getItems(): array {
    $items = [];

    if ($schedule = $this->device->getSchedule()) {
      foreach ($schedule->get('items') as $item) {
        $items[] = $item->getValue();
      }
    }

    return $items;
  }

  /**
   * @param bool $debug
   * @param bool $reload_css
   * @param bool $reload_assets
   *
   * @return array
   */
  public function getSpec($debug = FALSE, $reload_css = FALSE, $reload_assets = FALSE): array {
    return [
      'api' => Url::fromRoute('digital_signage_framework.api', [], [
        'absolute' => TRUE,
      ])->toString(),
      'deviceId' => $this->device->id(),
      'items' => $this->getItems(),
      'debug' => $debug,
      'reloadcss' => $reload_css,
      'reloadassets' => $reload_assets,
    ];
  }

}
